# Lurlene
Python-based live-coding language optimised for a small number of channels.

[![Build Status](https://travis-ci.org/combatopera/Lurlene.svg?branch=master)](https://travis-ci.org/combatopera/Lurlene)
